#ifndef GDBINSPECTOR_H
#define GDBINSPECTOR_H 

#include <Foundation/NSObject.h>

@class NSObject;
@class NSString;
@class NSWindow;

@interface GDBInspector : NSObject
{
  id object;
  NSWindow* window;
}

- (void) dealloc;

/**
 * Returns the object being inspected. Returns nil when no object
 * is being inspected. 
 */
- (id) object;

/**
  * Returns the window that contains the view of the inspector. The
  * default implementatin returns nil.
  */
- (NSWindow*) window;

/**
  * Called by GDBInspector to indicate that the inspected object has
  * changed. The default implementation is empty.
  */
- (void) objectDidChange;

/**
  * Priority for this inspector when inserted into the list.
  * Higher numbers place it closer to the end of the list.
  * Defaults to 0.0
  */
- (float) priority;

/**
  * Title of this inspector to be displayed in the inspector panel.
  */
- (NSString*) title;
@end

#endif /* GDBINSPECTOR_H */
