#include "GDBInspectorManager.h"
#include "GDBInspector.h"

#include <Foundation/NSArray.h>
#include <Foundation/NSEnumerator.h>
#include <AppKit/NSNib.h>
#include <AppKit/NSButton.h>
#include <AppKit/NSPopUpButton.h>
#include <AppKit/NSWindowController.h>

@implementation GDBInspectorManager

static GDBInspectorManager *sharedInstance = nil;

- (id) init
{
  NSNib *nib;
  [super init];
  inspectors = [NSMutableArray new];

  sharedWindowController = [[NSWindowController alloc] 
    initWithWindowNibName:@"ProjectInspector" owner:self];
  RELEASE(nib);
  return self;
}

- (void) dealloc
{
  RELEASE(inspectors);
  [super dealloc];
}

+ (GDBInspectorManager*) sharedInspectorManager
{
  if (!sharedInstance)
    sharedInstance = [[GDBInspectorManager alloc] init];
  return sharedInstance;
}

- (NSArray*) inspectors
{
  return [NSArray arrayWithArray:inspectors];
}

- (GDBInspector*) currentInspector
{
  return currentInspector;
}

- (void) addInspector:(GDBInspector*)inspector
{
  float priority;
  int index = 0;
  NSEnumerator *en;
  id currInspector;

  priority = [inspector priority];
  en = [inspectors reverseObjectEnumerator];
  while ((currInspector = [en nextObject]) != nil)
  {
    if ([currInspector priority] <= priority)
    {
      index = [inspectors indexOfObject:currInspector];
      break;
    }
  }
  
  [inspectors insertObject:inspector atIndex:index];
  [inspectorsList insertItemWithTitle:[inspector title]
    atIndex:index];
}

- (NSWindowController*) sharedWindowController
{
  return sharedWindowController;
}
@end
