#ifndef GDBSESSION_H
#define GDBSESSION_H

#include "GDBResult.h"
@class NSObject;
@class NSString;
@class NSMutableString;
@class NSFileHandle;
@class NSTask;
@class NSNotification;
@class GDBResult;

enum _GDBStreamIdentifier
{
  GDBNilStreamIdentifier,
  GDBResultStreamIdentifier,
  GDBCLIStreamIdentifier,
  GDBTargetOutputStreamIdentifier,
  GDBInternalStreamIdentifier,
  GDBOutOfBandStreamIdentifier
};
typedef enum _GDBStreamIdentifier GDBStreamIdentifier;

enum _GDBTargetStatus
{
  GDBTargetNotRunning,
  GDBTargetRunning,
  GDBTargetInterrupted
};
typedef enum _GDBTargetStatus GDBTargetStatus;


@interface GDBSession : NSObject
{
  NSTask *sessionTask;
  NSFileHandle *sessionInput, *sessionOutput, *slavePty;
  ////NSPipe *inputPipe, *outputPipe;

  NSMutableString *inputBuffer;

  NSString *target;
  GDBTargetStatus targetStatus;

  id delegate;
}

- (id) init;
- (void) dealloc;

- (void) setDelegate:(id)del;
- (id) delegate;

- (void) start;
- (void) terminate;
- (BOOL) isRunning;

- (void) setTarget:(NSString*)target;
- (NSString*) target;
- (GDBTargetStatus) targetStatus;

- (void) interruptTarget;
- (GDBResult*) executeSynchronousCommand:(NSString*)comm
  arguments:(NSString*)arguments;
- (id) nilStreamProcessor:(NSString*)record;
- (id) consoleStreamProcessor:(NSString*)record;
- (id) outOfBandStreamProcessor:(NSString*)record;
- (id) resultStreamProcessor:(NSString*)record;

- (SEL) processorForStreamWithToken:(unichar)token;
- (GDBStreamIdentifier) streamIdentifierWithToken:(unichar)token;
- (GDBResultClass) resultClassWithString:(NSString*)aString;
- (BOOL) parseInputBuffer:(GDBResult**)res;
- (BOOL) parseInputBufferUntilResult:(GDBResult**)result;
- (BOOL) parseResultRecord:(NSString*)record class:(NSString**)recordClass records:(NSDictionary**)records;
- (NSDictionary*) parseResultDictionary:(const char*)record withStartPosition:(int*)pos;
- (NSArray*) parseResultArray:(const char*)record withStartPosition:(int*)pos;
- (NSString*) parseResultString:(const char*)record withStartPosition:(int*)pos;

- (void) waitForInputAndNotify;

/* Notification handlers */
- (void) receivedTaskOutput:(NSNotification*)notification;
@end


@interface NSObject (GDBSessionDelegate)
- (void) session:(GDBSession*)session targetDidChangeStatus:(GDBTargetStatus)
  newStatus;
- (void) session:(GDBSession*)session targetOutput:(NSString*)output;
- (void) session:(GDBSession*)session debuggerOutput:(NSString*)output;
- (void) session:(GDBSession*)session debuggerInternalOutput:(NSString*)output;
- (void) sessionDiedUnexpectedly:(GDBSession*)session ;
@end

#endif /* GDBSESSION_H */
